@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # ------------------------------------------------------------------------------
 #
-#   Copyright 2018-2019 Fetch.AI Limited
+#   Copyright 2018-2023 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -24,6 +24,7 @@ import json
 import logging
 import time
 from collections import namedtuple
+from itertools import chain
 from json.decoder import JSONDecodeError
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, cast
@@ -40,6 +41,7 @@ from cosmpy.auth.rest_client import AuthRestClient
 from cosmpy.bank.rest_client import BankRestClient, QueryBalanceRequest
 from cosmpy.common.rest_client import RestClient
 from cosmpy.cosmwasm.rest_client import CosmWasmRestClient
+from cosmpy.crypto.hashfuncs import ripemd160
 from cosmpy.protos.cosmos.auth.v1beta1.auth_pb2 import BaseAccount
 from cosmpy.protos.cosmos.auth.v1beta1.query_pb2 import QueryAccountRequest
 from cosmpy.protos.cosmos.bank.v1beta1.tx_pb2 import MsgSend
@@ -60,8 +62,8 @@ from cosmpy.protos.cosmos.tx.v1beta1.tx_pb2 import (
     Tx,
     TxBody,
 )
-from cosmpy.protos.cosmwasm.wasm.v1beta1.query_pb2 import QuerySmartContractStateRequest
-from cosmpy.protos.cosmwasm.wasm.v1beta1.tx_pb2 import (
+from cosmpy.protos.cosmwasm.wasm.v1.query_pb2 import QuerySmartContractStateRequest
+from cosmpy.protos.cosmwasm.wasm.v1.tx_pb2 import (
     MsgExecuteContract,
     MsgInstantiateContract,
     MsgStoreCode,
@@ -94,9 +96,9 @@ DEFAULT_FAUCET_URL = "INVALID_URL"
 DEFAULT_ADDRESS = "https://cosmos.bigdipper.live"
 DEFAULT_CURRENCY_DENOM = "uatom"
 DEFAULT_CHAIN_ID = "cosmoshub-3"
-DEFAULT_GAS_AMOUNT = 1500000
+DEFAULT_GAS_AMOUNT = 1550000
 # Txs will fail if gas_limit is higher than MAXIMUM_GAS_AMOUNT
-MAXIMUM_GAS_AMOUNT = 1500000
+MAXIMUM_GAS_AMOUNT = 2000000
 _BYTECODE = "wasm_byte_code"
 
 
@@ -126,7 +128,7 @@ class DataEncrypt:
         password: str, salt: Optional[bytes] = None
     ) -> Tuple[bytes, bytes]:
         salt = salt or get_random_bytes(16)
-        key = scrypt(password, salt, 16, N=2 ** 14, r=8, p=1)  # type: ignore
+        key = scrypt(password, salt, 16, N=2**14, r=8, p=1)  # type: ignore
         return key, salt  # type: ignore
 
     @classmethod
@@ -227,8 +229,8 @@ class CosmosHelper(Helper):
                 )
         return is_successful
 
-    @staticmethod
-    def get_code_id(tx_receipt: JSONLike) -> Optional[int]:
+    @classmethod
+    def get_code_id(cls, tx_receipt: JSONLike) -> Optional[int]:
         """
         Retrieve the `code_id` from a transaction receipt.
 
@@ -237,18 +239,28 @@ class CosmosHelper(Helper):
         """
         code_id: Optional[int] = None
         try:
-            res = [
-                dic_["value"]  # type: ignore
-                for dic_ in tx_receipt["logs"][0]["events"][0]["attributes"]  # type: ignore
-                if dic_["key"] == "code_id"  # type: ignore
-            ]
-            code_id = int(res[0])
+            attributes = cls.get_event_attributes(tx_receipt)
+
+            code_id = int(attributes["code_id"])
         except (KeyError, IndexError):  # pragma: nocover
             code_id = None
         return code_id
 
     @staticmethod
-    def get_contract_address(tx_receipt: JSONLike) -> Optional[str]:
+    def get_event_attributes(tx_receipt: JSONLike) -> Dict:
+        """
+        Retrieve events attributes from tx receipt.
+
+        :param tx_receipt: the receipt of the transaction.
+        :return: dict
+        """
+        return {
+            i["key"]: i["value"]
+            for i in chain(*[i["attributes"] for i in tx_receipt["logs"][0]["events"]])  # type: ignore
+        }
+
+    @classmethod
+    def get_contract_address(cls, tx_receipt: JSONLike) -> Optional[str]:
         """
         Retrieve the `contract_address` from a transaction receipt.
 
@@ -257,19 +269,19 @@ class CosmosHelper(Helper):
         """
         contract_address: Optional[str] = None
         try:
-            res = [
-                dic_["value"]  # type: ignore
-                for dic_ in tx_receipt["logs"][0]["events"][0]["attributes"]  # type: ignore
-                if dic_["key"] == "contract_address"  # type: ignore
-            ]  # type: ignore
-            contract_address = res[0]
+            attributes = cls.get_event_attributes(tx_receipt)
+            contract_address = attributes["_contract_address"]
         except (KeyError, IndexError):  # pragma: nocover
             contract_address = None
         return contract_address
 
     @staticmethod
     def is_transaction_valid(
-        tx: JSONLike, seller: Address, client: Address, tx_nonce: str, amount: int,
+        tx: JSONLike,
+        seller: Address,
+        client: Address,
+        tx_nonce: str,
+        amount: int,
     ) -> bool:
         """
         Check whether a transaction is valid or not.
@@ -321,7 +333,7 @@ class CosmosHelper(Helper):
         """
         public_key_bytes = bytes.fromhex(public_key)
         s = hashlib.new("sha256", public_key_bytes).digest()
-        r = hashlib.new("ripemd160", s).digest()
+        r = ripemd160(s)
         five_bit_r = convertbits(r, 8, 5)
         if five_bit_r is None:  # pragma: nocover
             raise AEAEnforceError("Unsuccessful bech32.convertbits call")
@@ -360,7 +372,10 @@ class CosmosHelper(Helper):
         """
         signature_b64 = base64.b64decode(signature)
         verifying_keys = VerifyingKey.from_public_key_recovery(
-            signature_b64, message, SECP256k1, hashfunc=hashlib.sha256,
+            signature_b64,
+            message,
+            SECP256k1,
+            hashfunc=hashlib.sha256,
         )
         public_keys = [
             verifying_key.to_string("compressed").hex()
@@ -494,7 +509,9 @@ class CosmosCrypto(Crypto[SigningKey]):
         :return: signature of the message in string form
         """
         signature_compact = self.entity.sign_deterministic(
-            message, hashfunc=hashlib.sha256, sigencode=sigencode_string_canonize,
+            message,
+            hashfunc=hashlib.sha256,
+            sigencode=sigencode_string_canonize,
         )
         signature_base64_str = base64.b64encode(signature_compact).decode("utf-8")
         return signature_base64_str
@@ -506,7 +523,6 @@ class CosmosCrypto(Crypto[SigningKey]):
         :param transaction: the transaction to be signed
         :return: signed transaction
         """
-
         tx = ParseDict(transaction["tx"], Tx())
 
         # If public key is not already part of transaction
@@ -751,8 +767,6 @@ class _CosmosApi(LedgerApi):
         tx_fee: int = 0,
         gas: int = DEFAULT_GAS_AMOUNT,
         memo: str = "",
-        source: str = "",
-        builder: str = "",
     ) -> Optional[JSONLike]:
         """
         Create a CosmWasm bytecode deployment transaction.
@@ -766,19 +780,14 @@ class _CosmosApi(LedgerApi):
         :param tx_fee: the transaction fee.
         :param gas: Maximum amount of gas to be used on executing command.
         :param memo: any string comment.
-        :param source: the source.
-        :param builder: the builder.
         :return: the unsigned CosmWasm contract deploy message
         """
         store_msg = MsgStoreCode(
             sender=str(deployer_address),
             wasm_byte_code=base64.b64decode(contract_interface[_BYTECODE]),
-            source=source,
-            builder=builder,
         )
         store_msg_packed = ProtoAny()
         store_msg_packed.Pack(store_msg, type_url_prefix="/")  # type: ignore
-
         tx_fee_coins = [Coin(denom=tx_fee_denom, amount=str(tx_fee))]
         tx = self._get_transaction(
             account_numbers=[account_number],
@@ -836,7 +845,7 @@ class _CosmosApi(LedgerApi):
         init_msg = MsgInstantiateContract(
             sender=str(deployer_address),
             code_id=code_id,
-            init_msg=json.dumps(init_msg).encode("UTF8"),
+            msg=json.dumps(init_msg).encode("UTF8"),
             label=label,
             funds=init_funds,
         )
@@ -1123,9 +1132,10 @@ class _CosmosApi(LedgerApi):
 
         :return: the transaction
         """
-
         if pub_keys is not None and len(pub_keys) != len(from_addresses):
-            raise RuntimeError("Number of pubkeys is not equal to number of addresses")
+            raise RuntimeError(
+                "Number of pubkeys is not equal to number of addresses"
+            )  # pragma: nocover
 
         denom = denom if denom is not None else self.denom
         chain_id = chain_id if chain_id is not None else self.chain_id
@@ -1223,7 +1233,9 @@ class _CosmosApi(LedgerApi):
             single = ModeInfo.Single(mode=SignMode.SIGN_MODE_DIRECT)
             mode_info = ModeInfo(single=single)
             signer_info = SignerInfo(
-                public_key=from_pub_key_packed, mode_info=mode_info, sequence=sequence,
+                public_key=from_pub_key_packed,
+                mode_info=mode_info,
+                sequence=sequence,
             )
             signer_infos.append(signer_info)
 
@@ -1234,7 +1246,8 @@ class _CosmosApi(LedgerApi):
 
         # Prepare auth info
         auth_info = AuthInfo(
-            signer_infos=signer_infos, fee=Fee(amount=tx_fee, gas_limit=gas),
+            signer_infos=signer_infos,
+            fee=Fee(amount=tx_fee, gas_limit=gas),
         )
 
         # Prepare Tx body
@@ -1268,7 +1281,7 @@ class _CosmosApi(LedgerApi):
         if account_response.account.Is(BaseAccount.DESCRIPTOR):
             account_response.account.Unpack(account)
         else:
-            raise TypeError("Unexpected account type")
+            raise TypeError("Unexpected account type")  # pragma: nocover
 
         return account.account_number, account.sequence
 
@@ -1279,7 +1292,6 @@ class _CosmosApi(LedgerApi):
         :param tx_signed: the signed transaction
         :return: tx_digest, if present
         """
-
         tx = ParseDict(tx_signed["tx"], Tx())
 
         tx_data = tx.SerializeToString()
@@ -1291,7 +1303,9 @@ class _CosmosApi(LedgerApi):
         if broad_tx_resp.tx_response.code != 0:
             raw_log = broad_tx_resp.tx_response.raw_log
 
-            _default_logger.warning(f"Sending transaction failed: {raw_log}")
+            _default_logger.warning(
+                f"Sending transaction failed: {raw_log} {broad_tx_resp}"
+            )
             tx_digest = None
         else:
             tx_digest = broad_tx_resp.tx_response.txhash
@@ -1337,7 +1351,7 @@ class _CosmosApi(LedgerApi):
         # Cosmos does not distinguish between transaction receipt and transaction
         tx_with_receipt = self._try_get_transaction_with_receipt(tx_digest)
         if tx_with_receipt is None:
-            return None
+            return None  # pragma: nocover
         return {"tx": tx_with_receipt.get("tx")}
 
     def get_contract_instance(
@@ -1427,9 +1441,9 @@ class CosmosFaucetApi(FaucetApi):
                 break
 
             # if the status is failure
-            if (
-                status.status != self.FAUCET_STATUS_PENDING
-                and status.status != self.FAUCET_STATUS_PROCESSING
+            if status.status not in (
+                self.FAUCET_STATUS_PENDING,
+                self.FAUCET_STATUS_PROCESSING,
             ):  # pragma: nocover
                 raise RuntimeError(f"Failed to get wealth for {address}")
 
@@ -1500,7 +1514,10 @@ class CosmosFaucetApi(FaucetApi):
         if "txStatus" in data["claim"]:
             tx_digest = data["claim"]["txStatus"]["hash"]
 
-        return CosmosFaucetStatus(tx_digest=tx_digest, status=data["claim"]["status"],)
+        return CosmosFaucetStatus(
+            tx_digest=tx_digest,
+            status=data["claim"]["status"],
+        )
 
     @classmethod
     def _faucet_request_uri(cls, url: Optional[str] = None) -> str:
